@@ -1,4 +1,6 @@
 from .__version__ import __version__
 
 from .config import Config
+from .metadata import Metadata
+from .ref import Ref
 from .utils import get_config_object_from_proxy
