@@ -155,8 +155,10 @@ class Config(object):
         """
         if conf is None:
             conf = {}
+
         if isinstance(conf, Config):
-            conf = conf.serialize_to_dict()
+            conf = dict((key, conf.get_config(key)) for key in conf.keys())
+
         for key, value in itertools.chain(iteritems(conf), iteritems(kw)):
             if isinstance(value, dict):
                 if key not in self._value:
@@ -165,6 +167,7 @@ class Config(object):
             else:
                 self._value[key] = value
 
+
     def keys(self):
         """
         Similar to ``dict.keys()`` - returns iterable of all keys in the config object
@@ -209,6 +212,12 @@ class Config(object):
             self._backups = []
         self._backups.append(_get_state(self))
 
+    def discard_backup(self):
+        """
+        Discards the latest backup made
+        """
+        self._backups.pop()
+
     def restore(self):
         """
         Restores the most recent backup of the configuration under this child
